.. _components_introduction:

============
Introduction
============

Following and introduction to the elements of zfit

.. toctree::
    :maxdepth: 1

    space
    parameter
    model
    data
    loss
    minimize
    result
    toy_studies
